Learn R Programming

MMDai (version 1.2.0)

JointTableEst: Joint distribution table estimation This function is used to esitmate joint distribution table based on theta and psi

Description

Joint distribution table estimation This function is used to esitmate joint distribution table based on theta and psi

Usage

JointTableEst(theta, psi)

Arguments

theta

- vector of probability for each component

psi

- specific probability for each variable in each component

Value

table - joint distribution table