Learn R Programming

MMDai (version 1.2.0)

ParEst: Estimate theta and psi in multinomial mixture model

Description

This function is used to estimate theta and psi in multinomial mixture model given the number of components k.

Usage

ParEst(data, d, k, T = 1000)

Arguments

data

- data in matrix formation with n rows and p columns

d

- number of categories for each variable

k

- number of components

T

- number of iterations in Gibbs sampler, default value is 1000. T should be an even number for 'burn-in'.

Value

theta - vector of probability for each component

psi - specific probability for each variable in each component