Learn R Programming

MMDai (version 0.1.0)

k_identifier: Identify the number of components k

Description

This function is applied when number of components k is unknown and number of trials m > 2k -1. Missing data is allowed in dataset. This function identifies the number of components. Then if needed, parameters could be estimated by function FinMix().

Usage

k_identifier(data, T = 1000)

Arguments

data
- an array with dimension c(n,p,d). data[i,j,c] denotes the number of trials occurs in i-th observation, j-th variable and c-th categories.
T
- number of iterations in Gibbs sampler, default value is 1000. T should be an even number for 'burn-in'. The estimates are computed by the second-half iterations.

Value

k - number of components

References

[1] Elmore, Ryan, and Shaoli Wang. "ldentifiability and Estimation in Finite Mixture Models with Multinomial Components."

Examples

Run this code
## IncompleteData example
data("IncompleteData")
k_identifier(data = IncompleteData$data)

Run the code above in your browser using DataLab