- a vector which denotes the number of categories for each variable. It could be distinct among variables.
method
- the method to generate random datasets, including "MixMultinomial" and "General".
In "MixMultinomial" method, the dataset follows finite mixture of multinomial distribution
In "General" method, the dataset follows general joint distribution.
k
- parameter used in "MixMultinomial" method
theta
- parameter used in "MixMultinomial" method
psi
- parameter used in "MixMultinomial" method
JT
- parameter used in "General" method
Value
data - generated random dataset, a matrix with n rows and p columns.