This function is used to find the suitable number of components k.
kIdentifier(data, d, T = 1000, alpha = 0.25)- data in matrix formation with n rows and p columns
- number of categories for each variable
- number of iterations in Gibbs sampler, default value is 1000. T should be an even number for 'burn-in'.
- hyperparameter that could be regarded as the pseudo-count of the number of samples in the new component
k_est - posterior estimation of k
k_track - track of k in the iteration process